#!/bin/bash

# Copyright Jean-Philippe Guillemin <jp.guillemin@free.fr>. This program is free software; you can redistribute
# it and/or modify it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or (at your option)
# any later version. Please take a look at http://www.gnu.org/copyleft/gpl.htm

version='2.6.37.4'
pkgversion='70.1'
softname='brcm80211'

arch='i486'
cpu='i686'
Ktune=i486
Karch=x86
Kver=${version}

buildir=$(pwd)

srcdir="/usr/src/linux-${version}"

newdir="${softname}-${version}-${arch}-${pkgversion}"
PKG=/tmp/${newdir}

cd ${buildir}
rm -rf ${PKG}
rm -f ${PKG}.tgz

# Creating main directories
mkdir -p ${PKG}/lib/modules
mkdir -p ${PKG}${srcdir}
mkdir -p ${PKG}/etc/rc.d
mkdir -p ${PKG}/usr/{doc,src}/$softname-${version}

# Install the module
for file in $(find /lib/modules/$Kver -name brcm*) ; do 
	install -D -m644 $file ${PKG}$file
done
# Headers
for file in $(find /usr/src/linux-$Kver/include/config/ -name brcm*.h) ; do 
	install -D -m644 $file ${PKG}$file
done


# Creating rc.modules

cat << EOF > ${PKG}/etc/rc.d/rc.modules.new
#!/bin/sh
# rc.modules   $(date) <jp.guillemin@free.fr>
EOF


cat << "EOF" >> ${PKG}/etc/rc.d/rc.modules.new
#
# This file loads extra drivers into the Linux kernel.
# As kmod and udev handle module loading, this file will be mostly
# commented out, but is still useful for loading selected modules at boot time.
#

RELEASE=$(uname -r)

echo "Updating module dependencies for Linux $RELEASE"

/sbin/depmod -A


EOF

find /lib/modules -type f -iname *.ko | sed -e "s/^.*\/\(.*\)\.ko$/# \/sbin\/modprobe \1/m ; \
s/# \(.* ac$\)/\1/ ; \
s/# \(.* battery$\)/\1/ ; \
s/# \(.* button$\)/\1/ ; \
s/# \(.* fan$\)/\1/ ; \
s/# \(.* fuse$\)/\1/ ; \
s/# \(.* processor$\)/\1/ ; \
s/# \(.* thermal$\)/\1/ ; \
s/# \(.* lp$\)/\1/ ; \
s/# \(.* parport_pc$\)/\1/ ; \
s/# \(.* video$\)/\1/" | sort \
>> ${PKG}/etc/rc.d/rc.modules.new

chmod 755 ${PKG}/etc/rc.d/rc.modules.new


chown -R root:root ${PKG}

mkdir -p ${PKG}/install

cat << "EOF" >  ${PKG}/install/doinst.sh
config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
config etc/rc.d/rc.modules.new

EOF

cat << "EOF" > ${PKG}/install/slack-desc
brcm80211: Linux kernel module brcm80211
brcm80211: 
brcm80211: This module adds support for embedded wireless adapters 
brcm80211: based on Broadcom IEEE802.11n FullMAC chipsets.  
brcm80211: This driver uses the kernel's wireless extensions subsystem.
brcm80211:
brcm80211: 
brcm80211:
brcm80211: 
brcm80211: 
brcm80211: 
EOF


mkdir -p ${PKG}/usr/src/${softname}-${version}
cp ${buildir}/build-module.sh ${PKG}/usr/src/${softname}-${version}/build-${softname}.sh

cd ${PKG}
makepkg -p -l y -c n ${PKG}.txz

# cleanup
cd ${buildir}
rm -rf ${PKG}


